@@ -43,6 +43,7 @@ typedef struct _AttachInfo	AttachInfo;
 #endif
 
 #define COMPOSE_CHECK_BEFORE_SEND_HOOKLIST "compose_check_before_send"
+#define COMPOSE_CREATED_HOOKLIST "compose_created"
 
 typedef enum
 {
@@ -51,7 +52,8 @@ typedef enum
 	COMPOSE_BCC,
 	COMPOSE_REPLYTO,
 	COMPOSE_NEWSGROUPS,
-	COMPOSE_FOLLOWUPTO
+	COMPOSE_FOLLOWUPTO,
+	COMPOSE_INREPLYTO
 } ComposeEntryType;
 
 typedef enum
@@ -60,6 +62,7 @@ typedef enum
 	COMPOSE_REPLY_WITH_QUOTE,
 	COMPOSE_REPLY_WITHOUT_QUOTE,
 	COMPOSE_REPLY_TO_SENDER,
+	COMPOSE_REPLY_TO_ADDRESS,
 	COMPOSE_FOLLOWUP_AND_REPLY_TO,
 	COMPOSE_REPLY_TO_SENDER_WITH_QUOTE,
 	COMPOSE_REPLY_TO_SENDER_WITHOUT_QUOTE,
@@ -77,6 +80,15 @@ typedef enum
 	COMPOSE_REEDIT
 } ComposeMode;
 
+typedef enum {
+	PREF_ACCOUNT,
+	PREF_FOLDER,
+	PREF_TEMPLATE,
+	PREF_ML,
+	PREF_MAILTO,
+	PREF_NONE
+} ComposePrefType;
+
 typedef struct {
 	guint headernum;
 	Compose *compose;
@@ -84,6 +96,7 @@ typedef struct {
 	GtkWidget *entry;
 	GtkWidget *button;
 	GtkWidget *hbox;
+	ComposePrefType type;
 } ComposeHeaderEntry;
 
 struct _Compose
@@ -102,6 +115,7 @@ struct _Compose
 	/* Header */
 	GtkWidget *table_vbox;
 	GtkWidget *table;
+	GtkWidget *account_combo;
 	GtkWidget *subject_entry;
 	GtkWidget *paned;
 
@@ -146,6 +160,8 @@ struct _Compose
 	guint	   header_nextrow;
 	ComposeHeaderEntry *header_last;
 
+	GHashTable *email_hashtable;
+
 	gchar	*replyto;
 	gchar	*cc;
 	gchar	*bcc;
@@ -285,7 +301,8 @@ GList *compose_get_compose_list		(void);
 
 void compose_entry_append		(Compose	  *compose,
 					 const gchar	  *address,
-					 ComposeEntryType  type);
+					 ComposeEntryType  type,
+					 ComposePrefType   pref_type);
 
 
 gint compose_send			(Compose	  *compose);
@@ -298,6 +315,9 @@ void compose_destroy_all                (void);
 gboolean compose_draft	                (gpointer data, guint action);
 void compose_toolbar_cb			(gint 		action, 
 					 gpointer 	data);
+void compose_reply_to_address		(MessageView	*msgview,
+					 MsgInfo	*msginfo,
+					 const gchar	*address);
 void compose_reply_from_messageview	(MessageView 	*msgview, 
 					 GSList 	*msginfo_list, 
 					 guint 		 action);
@@ -321,4 +341,5 @@ void compose_close_toolbar		(Compose *compose);
 void compose_clear_exit_drafts		(void);
 void compose_reopen_exit_drafts		(void);
 void compose_attach_from_list (Compose *compose, GList *file_list, gboolean free_data);
+void compose_check_for_email_account(Compose *compose);
 #endif /* __COMPOSE_H__ */
